@@ -2,8 +2,8 @@ package Finance::Bank::SuomenVerkkomaksut;
 BEGIN {
   $Finance::Bank::SuomenVerkkomaksut::AUTHORITY = 'cpan:OKKO';
 }
-BEGIN {
-  $Finance::Bank::SuomenVerkkomaksut::VERSION = '0.004';
+{
+  $Finance::Bank::SuomenVerkkomaksut::VERSION = '0.005';
 }
 use Moose;
 use utf8;
@@ -12,6 +12,7 @@ use Data::Dumper;
 use JSON::XS;
 use Net::SSLeay qw/post_https make_headers/;
 use Digest::MD5 qw/md5_hex/;
+use MIME::Base64;
 
 # These are used when test_transaction() is set to true to signal a test payment is in effect.
 has 'test_merchant_id'     => ( is => 'ro', default => '13466' );
